package com.xlht.xlhtproject.service.impl;

import java.util.List;

import com.xlht.xlhtproject.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.xlht.xlhtproject.mapper.ZAssayMapper;
import com.xlht.xlhtproject.domain.ZAssay;
import com.xlht.xlhtproject.service.IZAssayService;

/**
 * 化验项目信息Service业务层处理
 * 
 * @author slibra
 * @date 2024-09-19
 */
@Service
public class ZAssayServiceImpl implements IZAssayService 
{
    @Autowired
    private ZAssayMapper zAssayMapper;

    /**
     * 查询化验项目信息
     * 
     * @param assayId 化验项目信息主键
     * @return 化验项目信息
     */
    @Override
    public ZAssay selectZAssayByAssayId(Long assayId)
    {
        return zAssayMapper.selectZAssayByAssayId(assayId);
    }

    /**
     * 查询化验项目信息列表
     * 
     * @param zAssay 化验项目信息
     * @return 化验项目信息
     */
    @Override
    public List<ZAssay> selectZAssayList(ZAssay zAssay)
    {
        return zAssayMapper.selectZAssayList(zAssay);
    }

    /**
     * 新增化验项目信息
     * 
     * @param zAssay 化验项目信息
     * @return 结果
     */
    @Override
    public int insertZAssay(ZAssay zAssay)
    {
        zAssay.setCreateTime(DateUtils.getNowDate());
        return zAssayMapper.insertZAssay(zAssay);
    }

    /**
     * 修改化验项目信息
     * 
     * @param zAssay 化验项目信息
     * @return 结果
     */
    @Override
    public int updateZAssay(ZAssay zAssay)
    {
        zAssay.setUpdateTime(DateUtils.getNowDate());
        return zAssayMapper.updateZAssay(zAssay);
    }

    /**
     * 批量删除化验项目信息
     * 
     * @param assayIds 需要删除的化验项目信息主键
     * @return 结果
     */
    @Override
    public int deleteZAssayByAssayIds(Long[] assayIds)
    {
        return zAssayMapper.deleteZAssayByAssayIds(assayIds);
    }

    /**
     * 删除化验项目信息信息
     * 
     * @param assayId 化验项目信息主键
     * @return 结果
     */
    @Override
    public int deleteZAssayByAssayId(Long assayId)
    {
        return zAssayMapper.deleteZAssayByAssayId(assayId);
    }
}
